@@ -1,15 +1,17 @@
 """Debugger module."""
 
-from ..esa import debug_esa_crema
+from ..esa import debug_esa_api, debug_esa_crema
 from ..misc import debug_cache, debug_download
 from ..spice import debug_spice_pool
-from ..trajectory import debug_trajectory
+from ..trajectory import debug_fovs, debug_trajectory
 
 
 __all__ = [
+    'debug_esa_api',
     'debug_esa_crema',
     'debug_cache',
     'debug_download',
     'debug_spice_pool',
     'debug_trajectory',
+    'debug_fovs',
 ]
