@@ -1,6 +1,6 @@
 """ESA events files module."""
 
-from ..events import Event, EventsFile, EventsList, EventWindow
+from ..events import EventsFile
 
 
 class EsaMissionPhases(EventsFile):
@@ -17,30 +17,27 @@ class EsaMissionTimeline(EventsFile):
         super().__init__(fname, primary_key='Event Name')
 
 
-class EsaMissionEvents(EventsFile, EventsList, EventWindow, Event):
+class EsaMissionEvents(EventsFile):
     """Generic ESA mission events file.
 
     By default, a header is appended to the file with the
     following parameters:
 
-    ``# name, t_start, t_end, subgroup, working_group``
+    .. code-block:: text
+
+        # name, t_start, t_end, subgroup, working_group
 
     but you can provide your own or set it to ``None`` is
     the first row is already the header.
 
-    The primary key is also initialized at ``'name'`` but you
+    The primary key is also initialized at ``name`` but you
     can use any other column.
 
     """
 
-    def __new__(cls, fname,
-                primary_key='name',
-                header='# name, t_start, t_end, subgroup, working_group'):
-        events = EventsFile(fname, primary_key=primary_key, header=header)
-
-        # Convert the object if only 1 event is present
-        if len(events) == 1:
-            key = list(events.keys())[0]
-            return events[key]
-
-        return events
+    def __init__(
+        self, fname,
+        primary_key='name',
+        header='# name, t_start, t_end, subgroup, working_group'
+    ):
+        super().__init__(fname, primary_key=primary_key, header=header)
