@@ -1,12 +1,13 @@
 """Events module."""
 
 from .csv import EventsFile
-from .event import Event, EventsList, EventWindow, timedelta
+from .event import Event, EventsDict, EventsList, EventWindow, timedelta
 
 
 __all__ = [
     'Event',
     'EventWindow',
+    'EventsDict',
     'EventsList',
     'EventsFile',
     'timedelta',
