@@ -1,6 +1,6 @@
 """Maps module."""
 
-from .map import CALLISTO, EARTH, EUROPA, GANYMEDE, MOON, IO, VENUS, Map
+from .map import CALLISTO, EARTH, EUROPA, GANYMEDE, IO, MOON, VENUS, Map
 
 
 __all__ = [
