@@ -16,6 +16,11 @@ class Equirectangular(GroundProjection):
 
     a.k.a. `Plate Carrée` and `Equidistant Cylindrical`.
 
+    Sources:
+
+    - https://proj.org/operations/projections/eqc.html
+    - https://github.com/proj4js/proj4js/blob/master/lib/projections/eqc.js
+
     Parameters
     ----------
     lon_e_0: float, optional
@@ -39,14 +44,9 @@ class Equirectangular(GroundProjection):
     Here, by default the longitudes are defined eastward in [0°, 360°],
     The false easting ``x_0``, if not provided, is automatically adjusted
     to make projected coordinates and real coordinates consistent.
-    You can fall back to the Earth convension (±180) with ``lon_e_0=0``
+    You can fall back to the Earth convension (±180°) with ``lon_e_0=0``
     attribute.
 
-    Source
-    ------
-    https://proj.org/operations/projections/eqc.html
-    https://github.com/proj4js/proj4js/blob/master/lib/projections/eqc.js
-
     """
 
     DEFAULT_RADIUS_KM = 180e-3 / np.pi   # Unitary degree representation
