@@ -35,7 +35,7 @@ class SubCategory(AbstractItem):
     Raises
     ------
     AttributeError:
-        If the :py:attr:`category` attribute is missing.
+        If the :attr:`category` attribute is missing.
 
     """
 
