@@ -55,7 +55,7 @@ class ROI(AbstractItem):
 
     Parameters
     ----------
-    key:
+    key: str or int
         Identification key.
     lons_e: [float, …]
         Polygon coordinates east longitudes.
@@ -64,7 +64,7 @@ class ROI(AbstractItem):
     name: str, optional
         Region name.
     **kwargs: str, optional
-        Region description/Science objective/Observation requirement/Color.
+        Region description / Science objective / Observation requirement / Color…
 
     """
 
@@ -96,8 +96,7 @@ class ROI(AbstractItem):
     def vertices(self, lonlat):
         """Vertices setter.
 
-        The vertices is automatically closed, if
-        the first and last point are different.
+        The vertices is automatically closed, if the first and last point are different.
 
         Parameters
         ----------
@@ -109,7 +108,8 @@ class ROI(AbstractItem):
         Raises
         ------
         ValueError:
-            If the east-longitude and latitude arrays are not the same
+            If the east-longitude and latitude arrays are not the same.
+
         """
         lons_e, lats = lonlat
 
@@ -213,21 +213,21 @@ class ROI(AbstractItem):
 
         Parameters
         ----------
-        pts: np.array
+        pts: numpy.ndarray
             List of geographic point(s): ``(lon_e, lat)`` or ``[(lon_e, lat), …]``.
-            If an object with :py:attr:`lonlat` attribute/property is provided,
+            If an object with :attr:`lonlat` attribute/property is provided,
             the intersection will be performed on these points.
 
         Returns
         -------
         np.array
-            Return ``TRUE`` if the point is inside the pixel corners, and
-            ``FALSE`` overwise.
+            Return ``True`` if the point is inside the pixel corners, and
+            ``False`` overwise.
 
         Warning
         -------
         The data need to be projected on a sphere first.
-        Here we project the :py:obj:`ROI` on a Equirectangular
+        Here we project the :obj:`ROI` on a Equirectangular
         plane before doing the intersection.
 
         Note
@@ -362,7 +362,7 @@ class ROIsCollection(AbstractCollection):
         Raises
         ------
         AttributeError
-            If the comparison object doest have a :py:func:`constains`
+            If the comparison object doest have a :func:`contains`
             test function.
 
         """
@@ -434,14 +434,14 @@ class ROIsCollectionWithCategories(ROIsCollection):
         Raises
         ------
         AttributeError:
-            If the provided `ITEM`` contain :py:attr:`category` or
-            :py:attr:`subcategory` attribute
+            If the provided `ITEM`` contain :attr:`category` or
+            :attr:`subcategory` attribute
 
         Note
         ----
-        If a :py:attr:`category` and a :py:attr:`subcategory` are provided
-        at the sametime, the :py:attr:`subcategory` parent ``category``
-        will overwrite the provided :py:attr:`category`.
+        If a :attr:`category` and a :attr:`subcategory` are provided
+        at the sametime, the :attr:`subcategory` parent ``category``
+        will overwrite the provided :attr:`category`.
 
         """
         if isinstance(item, self.ITEM):
