@@ -1,7 +1,11 @@
 """SPICE toolbox module."""
 
+from .abcorr import SpiceAbCorr
+from .datetime import datetime
 from .fov import SpiceFieldOfView
-from .pool import SPICEPool, SpicePool, debug_spice_pool
+from .kernel import format_data, kernel_parser
+from .metakernel import MetaKernel
+from .pool import SPICEPool, SpicePool, check_kernels, debug_spice_pool
 from .references import (
     SpiceBody, SpiceInstrument, SpiceObserver,
     SPICERef, SpiceRef, SpiceSpacecraft
@@ -10,12 +14,16 @@ from .times import et, et_ca_range, et_range, et_ranges, tdb, utc
 
 
 __all__ = [
+    'datetime',
     'et',
     'et_range',
     'et_ranges',
     'et_ca_range',
     'tdb',
     'utc',
+    'kernel_parser',
+    'format_data',
+    'SpiceAbCorr',
     'SpiceBody',
     'SpiceFieldOfView',
     'SpiceObserver',
@@ -23,6 +31,8 @@ __all__ = [
     'SpicePool',
     'SpiceRef',
     'SpiceSpacecraft',
+    'MetaKernel',
+    'check_kernels',
     'debug_spice_pool',
     'SPICERef',   # Depreciated
     'SPICEPool',  # Depreciated
