@@ -16,19 +16,20 @@ import spiceypy as sp
 def et(utc, *times):
     """Convert utc time to ephemeris time.
 
-    Parametes
-    ---------
+    Parameters
+    ----------
     utc: any
         Input UTC time. All SPICE time formats are accepted.
 
         For example:
-        - YYYY-MM-DDThh:mm:ss[.ms][Z]
-        - YYYY-MON-DD hh:mm:ss
 
-        Multiple iterable input (``slice``, ``list``,
-        ``tuples``, ``numpy.ndarray``) are accepted as well.
+        - ``YYYY-MM-DDThh:mm:ss[.ms][Z]``
+        - ``YYYY-MON-DD hh:mm:ss``
 
-        If an ``int`` or ``float`` is provided,
+        Multiple iterable input (:obj:`slice`, :obj:`list`,
+        :obj:`tuple`, :obj:`numpy.ndarray`) are accepted as well.
+
+        If an :obj:`int` or :obj:`float` is provided,
         the value is considered to be in ET and is not
         not converted.
 
@@ -38,7 +39,7 @@ def et(utc, *times):
     Caution
     -------
     The value is rounded at 1e-3 precision to avoid
-    conversion rounding error with datatime at `ms`
+    conversion rounding error with datatime at ``ms``
     precisions values.
 
     """
@@ -61,16 +62,17 @@ def et(utc, *times):
 def sclk(sc, utc, *times):
     """Convert utc time to spacecraft.
 
-    Parametes
-    ---------
+    Parameters
+    ----------
     sc: int
         NAIF spacecraft ID code.
     utc: str
         Input UTC time. All SPICE time formats are accepted.
 
         For example:
-            - YYYY-MM-DDThh:mm:ss[.ms][Z]
-            - YYYY-MON-DD hh:mm:ss
+
+        - ``YYYY-MM-DDThh:mm:ss[.ms][Z]``
+        - ``YYYY-MON-DD hh:mm:ss``
 
     *times: str
         Addition input UTC time(s) to parse.
@@ -89,8 +91,8 @@ def sclk(sc, utc, *times):
 def utc(et, *ets, unit='ms'):
     """Convert ephemeris time to UTC time(s) in ISOC format.
 
-    Parametes
-    ---------
+    Parameters
+    ----------
     et: str
         Input Ephemeris time.
     *ets: str
@@ -102,7 +104,7 @@ def utc(et, *ets, unit='ms'):
     -------
     numpy.datetime64 or [numpy.datetime64, …]
         Parsed time in ISOC format: ``YYYY-MM-DDThh:mm:ss.ms``
-        as numpy datetime64 object.
+        as :obj:`numpy.datetime64` object.
 
     """
     if ets:
@@ -117,8 +119,8 @@ def utc(et, *ets, unit='ms'):
 def tdb(et, *ets):
     """Convert ephemeris time to Barycentric Dynamical Time(s).
 
-    Parametes
-    ---------
+    Parameters
+    ----------
     et: str
         Input Ephemeris time.
     *ets: str
@@ -169,18 +171,18 @@ def parse_step(step):
 
     Examples of valid units:
 
-        - ms, msec, millisecond
-        - s, sec, second
-        - m, min, minute
-        - h, hour
-        - D, day
-        - M, month
-        - Y, year
+    - ``ms``, ``msec``, ``millisecond``
+    - ``s``, ``sec``, ``second``
+    - ``m``, ``min``, ``minute``
+    - ``h``, ``hour``
+    - ``D``, ``day``
+    - ``M``, ``month``
+    - ``Y``, ``year``
 
     Short unit version are accepted, but
-    `H` and `S` are not accepted to avoid
-    the confusion between `m = minute`
-    and `M = month`.
+    ``H`` and ``S`` are not accepted to avoid
+    the confusion between ``m = minute``
+    and ``M = month``.
 
     Plural units are also valid.
 
@@ -228,7 +230,7 @@ def et_range(start, stop, step='1s', endpoint=True):
     step: int or str, optional
         Temporal step to apply between the start
         and stop UTC times (default: `1s`).
-        If the :py:attr:`step` provided is an `int ≥ 2`
+        If the :py:attr:`step` provided is an `int >= 2`
         it will correspond to the number of samples
         to generate.
 
@@ -278,8 +280,8 @@ def et_ranges(*ranges):
     ----
     If a start time match the previous stop time, the two sequence will be merged.
 
-    SeeAlso
-    -------
+    See Also
+    --------
     et_range
 
     """
@@ -304,10 +306,14 @@ def et_ca_range(t, *dt, et_min=None, et_max=None):
     *dt: tuple(s), optional
         Temporal sequence around closest approach:
 
+        .. code-block:: text
+
             (duration, numpy.datetime unit, step value and unit)
 
         By default, the pattern is:
 
+        .. code-block::
+
             [
                 (10, 'm', '1 sec'),
                 (1, 'h', '10 sec'),
@@ -317,13 +323,13 @@ def et_ca_range(t, *dt, et_min=None, et_max=None):
 
         With will lead to the following sampling:
 
-            - 1 pt from CA -12 h to CA  -2 h every 10 min
-            - 1 pt from CA  -2 h to CA  -1 h every  1 min
-            - 1 pt from CA  -1 h to CA -10 m every 10 sec
-            - 1 pt from CA -10 m to CA +10 m every  1 sec
-            - 1 pt from CA +10 m to CA  +1 h every 10 sec
-            - 1 pt from CA  +1 h to CA  +2 h every  1 min
-            - 1 pt from CA  +2 h to CA +12 h every 10 min
+        - 1 pt from CA -12 h to CA  -2 h every 10 min
+        - 1 pt from CA  -2 h to CA  -1 h every  1 min
+        - 1 pt from CA  -1 h to CA -10 m every 10 sec
+        - 1 pt from CA -10 m to CA +10 m every  1 sec
+        - 1 pt from CA +10 m to CA  +1 h every 10 sec
+        - 1 pt from CA  +1 h to CA  +2 h every  1 min
+        - 1 pt from CA  +2 h to CA +12 h every 10 min
 
         = 2,041 points around the CA point.
 
