@@ -52,12 +52,10 @@ def rlonlat(pt):
 
     Returns
     -------
-    float
-        Point radius (in km).
-    float
-        East planetocentric longitude (in degree).
-    float
-        North planetocentric latitude (in degree).
+    float, float, float
+        - Point radius (in km).
+        - East planetocentric longitude (in degree).
+        - North planetocentric latitude (in degree).
 
     Note
     ----
@@ -66,7 +64,7 @@ def rlonlat(pt):
 
     See Also
     --------
-    spiceypy.reclat
+    spiceypy.spiceypy.reclat
 
     """
     big = np.max(np.abs(pt), axis=0)
@@ -100,10 +98,9 @@ def radec(vec):
 
     Returns
     -------
-    float or np.ndarray
-        Right-ascension (in degree).
-    float or np.ndarray
-        Declination angle (in degree).
+    float or numpy.ndarray, float or numpy.ndarray
+        - Right-ascension (in degree).
+        - Declination angle (in degree).
 
     See Also
     --------
@@ -136,11 +133,11 @@ def sub_obs_pt(time, observer, target, abcorr='NONE', method='NEAR POINT/ELLIPSO
         - 'NADIR/DSK/UNPRIORITIZED[/SURFACES = <surface list>]'
         - 'INTERCEPT/DSK/UNPRIORITIZED[/SURFACES = <surface list>]'
 
-        (See NAIF :func:`subpnt` for more details).
+        (See NAIF :func:`spiceypy.spiceypy.subpnt` for more details).
 
     Returns
     -------
-    (float, float, float) or np.ndarray
+    (float, float, float) or numpy.ndarray
         Sub-observer XYZ coordinates in the target body fixed frame
         (expressed in km).
 
@@ -149,7 +146,7 @@ def sub_obs_pt(time, observer, target, abcorr='NONE', method='NEAR POINT/ELLIPSO
 
     See Also
     --------
-    spiceypy.subpnt
+    spiceypy.spiceypy.subpnt
 
     """
     time = type_check(time, float, et)
@@ -172,6 +169,8 @@ def sc_state(time, spacecraft, target, abcorr='NONE'):
 
     The position vector starts from the target body to the spacecraft:
 
+    .. code-block:: text
+
         target ------> spacecraft
                 (km)
 
@@ -191,7 +190,7 @@ def sc_state(time, spacecraft, target, abcorr='NONE'):
 
     Returns
     -------
-    (float, float, float, float, float, float) or np.ndarray
+    (float, float, float, float, float, float) or numpy.ndarray
         Spacecraft XYZ position and velocity coordinates in
         the target body fixed frame (expressed in km and km/s).
 
@@ -200,7 +199,7 @@ def sc_state(time, spacecraft, target, abcorr='NONE'):
 
     See Also
     --------
-    spiceypy.spkezr
+    spiceypy.spiceypy.spkezr
 
     """
     time = type_check(time, float, et)
@@ -233,7 +232,7 @@ def attitude(time, observer, ref='J2000'):
 
     Returns
     -------
-    np.ndarray
+    numpy.ndarray
         C-matrix relative to the reference frame.
 
         If a list of time were provided, the results will be stored
@@ -246,7 +245,7 @@ def attitude(time, observer, ref='J2000'):
 
     See Also
     --------
-    spiceypy.pxform
+    spiceypy.spiceypy.pxform
 
     """
     time = type_check(time, float, et)
@@ -291,11 +290,11 @@ def intersect_pt(time, observer, target, frame, ray, limb=False,
         Aberration correction (default: 'None')
     method: str, optional
         Computation method to be used.
-        (See NAIF :func:`sincpt` for more details).
+        (See NAIF :func:`spiceypy.spiceypy.sincpt` for more details).
 
     Returns
     -------
-    (float, float, float) or np.ndarray
+    (float, float, float) or numpy.ndarray
         Surface/limb intersection XYZ position on the target body
         fixed frame (expressed in km).
 
@@ -309,8 +308,8 @@ def intersect_pt(time, observer, target, frame, ray, limb=False,
 
     See Also
     --------
-    spiceypy.sincpt
-    moon_coverage.spice.limb.limb_ip_pt
+    spiceypy.spiceypy.sincpt
+    .limb_ip_pt
 
     """
     time = type_check(time, float, et)
@@ -370,11 +369,11 @@ def boresight_pt(time, observer, target, limb=False, abcorr='NONE', method='ELLI
         Aberration correction (default: 'None')
     method: str, optional
         Computation method to be used.
-        (See NAIF :func:`sincpt` for more details).
+        (See NAIF :func:`spiceypy.spiceypy.sincpt` for more details).
 
     Returns
     -------
-    (float, float, float) or np.ndarray
+    (float, float, float) or numpy.ndarray
         Boresight intersection XYZ position on the target surface body
         fixed frame (expressed in km).
 
@@ -383,7 +382,7 @@ def boresight_pt(time, observer, target, limb=False, abcorr='NONE', method='ELLI
 
     See Also
     --------
-    intersection_pt
+    intersect_pt
 
     """
     observer = type_check(observer, SpiceObserver)
@@ -414,11 +413,11 @@ def fov_pts(time, inst, target, limb=False, npt=24,
         Aberration correction (default: 'None'),
     method: str, optional
         Computation method to be used.
-        (See NAIF :func:`sincpt` for more details).
+        (See NAIF :func:`spiceypy.spiceypy.sincpt` for more details).
 
     Returns
     -------
-    (float, float, float) or np.ndarray
+    (float, float, float) or numpy.ndarray
         Field of View intersection XYZ positions on the target surface body
         fixed frame (expressed in km).
 
@@ -427,7 +426,7 @@ def fov_pts(time, inst, target, limb=False, npt=24,
 
     See Also
     --------
-    intersection_pt
+    intersect_pt
 
     Note
     ----
@@ -460,14 +459,15 @@ def local_time(time, lon, target, lon_type='PLANETOCENTRIC'):
     lon_type: str, optional
         Form of longitude supplied by the variable :py:attr:`lon`.
         Possible values:
-            - `PLANETOCENTRIC` (default)
-            - `PLANETOGRAPHIC`
 
-        (See NAIF :func:`et2lst` for more details).
+        - `PLANETOCENTRIC` (default)
+        - `PLANETOGRAPHIC`
+
+        (See NAIF :func:`spiceypy.spiceypy.et2lst` for more details).
 
     Returns
     -------
-    float or np.ndarray
+    float or numpy.ndarray
         Local solar time (expressed in decimal hours).
 
         If a list of :py:attr:`time` or :py:attr:`lon`
@@ -482,7 +482,7 @@ def local_time(time, lon, target, lon_type='PLANETOCENTRIC'):
 
     See Also
     --------
-    spiceypy.et2lst
+    spiceypy.spiceypy.et2lst
 
     """
     time = type_check(time, float, et)
@@ -525,21 +525,22 @@ def illum_angles(time, observer, target, pt, abcorr='NONE', method='ELLIPSOID'):
         Observer name.
     target: str
         Target body name.
-    pt: np.ndarray
+    pt: numpy.ndarray
         Surface point (XYZ coordinates).
     abcorr: str, optional
         Aberration correction (default: 'None')
     method: str, optional
         Form of longitude supplied by the variable :py:attr:`lon`.
         Possible values:
-            - `ELLIPSOID` (default)
-            - `DSK/UNPRIORITIZED[/SURFACES = <surface list>]`
 
-        (See NAIF :func:`ilumin` for more details).
+        - `ELLIPSOID` (default)
+        - `DSK/UNPRIORITIZED[/SURFACES = <surface list>]`
+
+        (See NAIF :func:`spiceypy.spiceypy.ilumin` for more details).
 
     Returns
     -------
-    float or np.ndarray
+    float or numpy.ndarray
         Solar incidence, emission and phase angles at the surface point (degrees).
 
         If a list of time were provided, the results will be stored in a (3, N) array.
@@ -552,7 +553,7 @@ def illum_angles(time, observer, target, pt, abcorr='NONE', method='ELLIPSOID'):
 
     See Also
     --------
-    spiceypy.ilumin
+    spiceypy.spiceypy.ilumin
 
     """
     time = type_check(time, float, et)
@@ -592,6 +593,8 @@ def sun_pos(time, target, abcorr='NONE'):
 
     The vector starts from the target body to the Sun:
 
+    .. code-block:: text
+
         target ------> Sun
                 (km)
 
@@ -607,7 +610,7 @@ def sun_pos(time, target, abcorr='NONE'):
 
     Returns
     -------
-    (float, float, float) or np.ndarray
+    (float, float, float) or numpy.ndarray
         Sun XYZ coordinates in the target body fixed frame
         (expressed in km).
 
@@ -616,7 +619,7 @@ def sun_pos(time, target, abcorr='NONE'):
 
     See Also
     --------
-    spiceypy.spkpos
+    spiceypy.spiceypy.spkpos
 
     """
     time = type_check(time, float, et)
@@ -651,7 +654,7 @@ def solar_longitude(time, target, abcorr='NONE'):
 
     Returns
     -------
-    float or np.ndarray
+    float or numpy.ndarray
         Solar longitude angle(s) (degrees).
 
         If a list of :py:attr:`time` were provided,
@@ -664,7 +667,7 @@ def solar_longitude(time, target, abcorr='NONE'):
 
     See Also
     --------
-    spiceypy.lspcn
+    spiceypy.spiceypy.lspcn
 
     """
     time = type_check(time, float, et)
@@ -705,7 +708,7 @@ def true_anomaly(time, target, abcorr='NONE', frame='ECLIPJ2000'):
 
     Returns
     -------
-    float or np.ndarray
+    float or numpy.ndarray
         True anomaly angle (degrees).
 
         If a list of :py:attr:`time` were provided,
@@ -713,8 +716,8 @@ def true_anomaly(time, target, abcorr='NONE', frame='ECLIPJ2000'):
 
     See Also
     --------
-    spiceypy.spkezr
-    spiceypy.oscltx
+    spiceypy.spiceypy.spkezr
+    spiceypy.spiceypy.oscltx
 
     """
     time = type_check(time, float, et)
@@ -759,7 +762,7 @@ def groundtrack_velocity(target, state):
 
     Returns
     -------
-    float or np.ndarray
+    float or numpy.ndarray
         Ground track velocity (km/s).
 
         If a list of :py:attr:`state` is provided,
@@ -775,6 +778,8 @@ def groundtrack_velocity(target, state):
     The tangential speed is obtained as product of the local radius of the
     observed body with the tangential angular speed:
 
+    .. code-block:: text
+
         latitudinal
         component
             ^   x
@@ -788,9 +793,9 @@ def groundtrack_velocity(target, state):
 
     See Also
     --------
-    spiceypy.recgeo
-    spiceypy.dgeodr
-    spiceypy.mxv
+    spiceypy.spiceypy.recgeo
+    spiceypy.spiceypy.dgeodr
+    spiceypy.spiceypy.mxv
 
     """
     target = type_check(target, SpiceBody)
