@@ -7,7 +7,7 @@ import numpy as np
 
 from .trajectory import Flyby, Trajectory
 from ..esa import ESA_CREMAS
-from ..events.event import Event, EventsList, EventWindow
+from ..events.event import Event, EventsDict, EventsList, EventWindow
 from ..misc import cached_property, depreciated_renamed
 from ..spice import MetaKernel, SpiceAbCorr, SpicePool, check_kernels
 from ..spice.metakernel import MissingKernel, MissingKernelsRemote
@@ -23,7 +23,7 @@ class TourConfig:
 
     Parameters
     ----------
-    mk: kernels.MetaKernel or str, optional
+    mk: MetaKernel or str, optional
         Metakernel filename or ESA CReMA key.
         You can provide your own or use the one provided by ESA based
         on the spacecraft selected.
@@ -33,7 +33,7 @@ class TourConfig:
 
         Currently, ESA CReMA keyword are only implemented for ``JUICE``
         but more ESA missions could be added upon request.
-        See ``moon_coverage.esa.crema`` for more details.
+        See :class:`.EsaCremasCollection` for more details.
 
     kernels: str or pathlib.Path, optional
         Kernel filename or list of kernel filenames that will be loaded
@@ -55,14 +55,14 @@ class TourConfig:
     version: str, optional
         ESA metakernel SKD version / tag (default:`latest`).
         This parameter is only available for metakernel defined
-        with a key/shortcut and available in ``ESA_CREMAS``.
+        with a key/shortcut and available in :attr:`.ESA_CREMAS`.
 
     kernels_dir: str or pathlib.Path, optional
         Kernels directory location.
 
         This parameter is only used to subsitute the ``$KERNELS``
         symbol value at runtime in the provided metakernel.
-        This parameter has no effect on the :py:attr:`kernels` parameter.
+        This parameter has no effect on the :attr:`kernels` parameter.
 
         If no explicit value is provided (default), the tool will try to
         pull the kernel location from your environment variables configuration, i.e.
@@ -72,13 +72,15 @@ class TourConfig:
     download_kernels: bool, optional
         Try to download the missing kernels in the metakernel if they are
         missing (default: `False`).
-        This parameter has no effect on the :py:attr:`kernels` parameter.
+        This parameter has no effect on the :attr:`kernels` parameter.
 
-    autoload_kernels: bool, optional
-        Autoload the kernel pool (:py:func:`spiceypy.furnsh`)
-        with all the kernels (default: `True`).
-        If the autoloader is disabled, you need to use the
-        :py:func:`load_spice_pool` function to load the pool.
+    remote_kernels: str or int, optional
+        Remote kernel source. If none is provided (default), the content of
+        the file will be parsed to search for a remote base value (with ``://``).
+        If multiple remotes are present, the first one will be used by default.
+        You can provide an integer to choose which one you want to use.
+        This value is not required if all the kernel are present locally (it is only
+        used to download the missing kernels).
 
     default_time_step: str, optional
         Default time step if a temporal slice is provided without
@@ -89,21 +91,21 @@ class TourConfig:
         the target's position and orientation.
         Only the SPICE keys are accepted.
 
-    exclude: EventWindow or EventsList
-        Event window or list of events to exclude from the analysis.
+    exclude: EventWindow, EventsDict or EventsList
+        Event window, dict or list of events to exclude from the analysis.
 
     Raises
     ------
     ValueError
         If the metakernel is provided as a key/shortcut but the associated
-        spacecraft is not available in ``ESA_CREMAS``.
+        spacecraft is not available in :attr:`.ESA_CREMAS`.
 
     KernelsDirectoryNotFoundError
         If not kernels directory is supplied and the kernels were
         not found in the metakernel location.
 
     KernelNotFoundError
-        If some kernels are missing and :py:attr:`download_kernels`
+        If some kernels are missing and :attr:`download_kernels`
         is set to ``False``.
 
     KernelRemoteNotFoundError
@@ -115,7 +117,7 @@ class TourConfig:
     Tip
     ---
     If you need to replace a custom ``PATH_SYMBOLS`` different from `KERNELS`
-    you could provide a :py:class:`MetaKernel` object with the substituted values
+    you could provide a :class:`.MetaKernel` object with the substituted values
     in the initial call:
 
     >>> TourConfig(mk=MetaKernel('foo.tm', custom_symbol='CUSTOM_VALUE'))
@@ -127,7 +129,8 @@ class TourConfig:
     def __init__(self, mk='5.0', kernels=None,
                  spacecraft='JUICE', instrument='', target='Ganymede',
                  version='latest', kernels_dir=None, download_kernels=False,
-                 default_time_step='1 minute', abcorr='NONE', exclude=None):
+                 remote_kernels=0, default_time_step='1 minute', abcorr='NONE',
+                 exclude=None):
         # Properties
         self.spacecraft = spacecraft.upper()
         self.target = target.upper()
@@ -135,7 +138,7 @@ class TourConfig:
         self.exclude = exclude
 
         # Kernel setup
-        self.mk = mk, version, kernels_dir, download_kernels
+        self.mk = mk, version, kernels_dir, download_kernels, remote_kernels
         self._add(kernels)
 
         # Trajectory/Flyby default parameters
@@ -199,26 +202,26 @@ class TourConfig:
         ------
         ValueError
             If the metakernel is provided as a key/shortcut but the associated
-            spacecraft is not available in ``ESA_CREMAS``.
+            spacecraft is not available in :attr:`.ESA_CREMAS`.
 
         KernelsDirectoryNotFoundError
             If not kernels directory is supplied and the kernels were
             not found in the metakernel location.
 
         KernelNotFoundError
-            If some kernels are missing and :py:attr:`download_kernels`
+            If some kernels are missing and :attr:`download_kernels`
             is set to ``False``.
 
         KernelRemoteNotFoundError
             If the source of the kernels in the metakernel is unknown.
 
         """
-        mk, version, kernels_dir, download_kernels = args
+        mk, version, kernels_dir, download_kernels, remote_kernels = args
 
         if not isinstance(mk, (type(None), MetaKernel)):
 
             # Defined metakernels keyword arguments
-            kwargs = {'download': download_kernels}
+            kwargs = {'download': download_kernels, 'remote': remote_kernels}
 
             if kernels_dir is None:
                 kernels_dir = os.environ.get(f'KERNELS_{self.spacecraft}')
@@ -256,7 +259,7 @@ class TourConfig:
             except MissingKernelsRemote:
                 raise KernelRemoteNotFoundError(
                     'The source of the kernels in the metakernel is unknown. '
-                    'You can provide directly a `moon_coverage.MetaKernel` object '
+                    'You can provide directly a `MetaKernel` object '
                     'with an explicit `remote` attribute to fix this issue.')
 
         # Cache the metakernel
@@ -294,7 +297,7 @@ class TourConfig:
     def _parse(self, times):
         """Parse input times.
 
-        Method used in :py:func:`__getitem__` to query a trajectory
+        Method used in :func:`__getitem__` to query a trajectory
         on a temporal grid.
 
         Parameters
@@ -312,7 +315,7 @@ class TourConfig:
             - ``'2033-01-01T12:34:56'`` time string with or without
             explicit time. All the SPICE time formats are supported.
             No change is performed in this method (convertion to ET
-            is done in the :py:class:`Trajectory` initialization).
+            is done in the :class:`Trajectory` initialization).
 
             - ``numpy.datetime64`` can be used (it will be converted
             as an ISO time string later, no change here).
@@ -326,19 +329,19 @@ class TourConfig:
             to use the coverage first point.
             ``stop`` can be replaced by ``None|'stop'|'end'``
             to use the coverage last point.
-            If no explicit ``step`` is provided, the :py:attr:`default_time_step`
-            (provided in :py:func:`__init__`) will be used; if an ``int`` is
+            If no explicit ``step`` is provided, the :attr:`default_time_step`
+            (provided in :func:`__init__`) will be used; if an ``int`` is
             provided, it will correspond to the total number of points (evenly
             space in time).
 
             - ``list``, ``tuple``, ``numpy.array`` are only modified
-            when an :py:class:`Event` or an :py:class:`EventWindow`
+            when an :class:`Event` or an :class:`EventWindow`
             is provided (converted to ET later).
 
-            - :py:class:`Event` will extract the event time (single value).
+            - :class:`Event` will extract the event time (single value).
 
-            - :py:class:`EvenWindow` will extract the start and stop time of
-            the event window (the :py:attr:`default_time_step`)
+            - :class:`EvenWindow` will extract the start and stop time of
+            the event window (the :attr:`default_time_step`)
 
         Returns
         -------
@@ -358,7 +361,7 @@ class TourConfig:
         if isinstance(times, slice):
             return self._parse_slice(times)
 
-        if isinstance(times, (tuple, list, np.ndarray, EventsList)):
+        if isinstance(times, (tuple, list, np.ndarray, EventsDict, EventsList)):
             return [self._parse(t) for t in times]
 
         return times
@@ -369,14 +372,24 @@ class TourConfig:
 
         if start in [None, 'start', 'beg', 'begin', 'begining']:
             start = self.coverage[0]
+
         elif isinstance(start, Event):
             start = start.start
+            if not isinstance(stop, Event):
+                return start
+
         elif isinstance(start, EventWindow):
             # EventWindow:'1h' -> the step is moved from `stop` to `step`
             start, stop, step = start.start, start.stop, stop
 
+        elif isinstance(start, (EventsDict, EventsList)):
+            # Events:'1h' -> the step is moved from `stop` to `step`
+            events, step = start, stop
+            return [self._parse_slice(slice(event, step)) for event in events]
+
         if stop in [None, 'stop', 'end']:
             stop = self.coverage[1]
+
         elif isinstance(stop, Event):
             stop = stop.stop
 
@@ -407,14 +420,14 @@ class TourConfig:
 
         Parameters
         ----------
-        event: events.EventWindow or events.EventsList, optional
+        event: EventWindow, EventsDict or EventsList, optional
             Optional event. If none is provided (default), the full
             coverage window will be used with a time step of 30 minutes.
         default_time_step: str, optional
             Default time step grid to search the location of the minimum
-            of altitude in the flyby (default=``30 mins``).
+            of altitude in the flyby (default: ``'30 mins'``).
         alt_min: float, optional
-            Minimal altitude at closest approach (default: 25,000 km).
+            Minimal altitude at closest approach (default: ``25,000`` km).
 
         Returns
         -------
@@ -430,7 +443,7 @@ class TourConfig:
 
         See Also
         --------
-        :py:func:`get_flybys` if you need a different minimal altitude.
+        :func:`get_flybys` if you need a different minimal altitude.
 
         """
         return self.get_flybys()
@@ -440,31 +453,35 @@ class TourConfig:
 
         Parameters
         ----------
-        approx_ca_date: float, string or numpy.datetime64
+        approx_ca_date: float, str or numpy.datetime64
             Approximate CA datetime (at day level).
             This value will be re-computed (at the second level).
-            :py:class:`Event`, :py:class:`Eventwindow` and
-            :py:class:`EventList` can be used as well.
+            :class:`.Event`,
+            :class:`.EventWindow`,
+            :class:`.EventsDict` and
+            :class:`.EventsList` can be used as well.
 
         *dt: tuple(s), optional
             Temporal sequence around closest approach:
 
-            `(duration, numpy.datetime unit, step value and unit)`
+            .. code-block:: text
 
-            See :py:func:`moon_coverage.spice.et_ca_range` for more details.
+                (duration, numpy.datetime unit, step value and unit)
+
+            See :func:`.et_ca_range` for more details.
 
         alt_min: float, optional
             Minimal altitude at closest approach (default: 25,000 km).
 
         Returns
         -------
-        moon_coverage.trajectory.SpacecraftFlyby or
-        moon_coverage.trajectory.InstrumentFlyby
-            If an :py:attr:`instrument` was provided.
+        SpacecraftFlyby or InstrumentFlyby
+            Flyby trajectory.
 
-            If an :py:class:`Eventwindow` or an
-            :py:class:`EventList` is provided, the output
-            will be a list of the flybys found in these intervales.
+        Note
+        ----
+        If an :class:`.EventWindow`, :class:`.EventsDict` or an :class:`.EventsList`
+        is provided, the output will be a list of the flybys found in these intervales.
 
         """
         if isinstance(approx_ca_date, Event):
@@ -473,7 +490,7 @@ class TourConfig:
         elif isinstance(approx_ca_date, EventWindow):
             return self.get_flybys(event=approx_ca_date, alt_min=alt_min)
 
-        elif isinstance(approx_ca_date, (list, EventsList)):
+        elif isinstance(approx_ca_date, (list, EventsDict, EventsList)):
             return [
                 self.flyby(event, *dt, alt_min=alt_min)
                 for event in approx_ca_date
