@@ -67,11 +67,11 @@ def segment_trajectory_property(func):
 class MaskedSpacecraftTrajectory:  # pylint: disable=too-many-public-methods
     """Masked spacecraft trajectroy object.
 
-    Paramters
-    ---------
+    Parameters
+    ----------
     traj:
         Original trajectory.
-    mask: np.ndarray
+    mask: numpy.ndarray
         Bool list of the points to mask.
 
     """
@@ -298,8 +298,8 @@ class MaskedInstrumentTrajectory(MaskedSpacecraftTrajectory):
 class SegmentedSpacecraftTrajectory:  # pylint: disable=too-many-public-methods
     """Segmented spacecraft trajectroy object.
 
-    Paramters
-    ---------
+    Parameters
+    ----------
     traj:
         Original trajectory.
     segment: slice
