@@ -4,7 +4,7 @@ import numpy as np
 
 from .fovs import FovsCollection
 from .mask_traj import MaskedInstrumentTrajectory, MaskedSpacecraftTrajectory
-from ..events import EventsList, EventWindow
+from ..events import EventsDict, EventsList, EventWindow
 from ..math.vectors import angle, ell_norm, norm
 from ..misc import cached_property, logger
 from ..spice import (
@@ -29,10 +29,10 @@ class Trajectory:  # pylint: disable=too-many-public-methods
     kernels: str or tuple
         List of kernels to be loaded in the SPICE pool.
 
-    observer: str or spice.SpiceSpacecraft or spice.SpiceInstrument
+    observer: str or SpiceSpacecraft or SpiceInstrument
         Observer (spacecraft or instrument) SPICE reference.
 
-    target: str or spice.SpiceBody
+    target: str or SpiceBody
         Target SPICE reference.
 
     ets: float or str or list
@@ -43,8 +43,8 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         the target's position and orientation.
         Only the SPICE keys are accepted.
 
-    exclude: EventWindow or EventsList
-        Event window or list of events to exclude from the analysis.
+    exclude: EventWindow, EventsDict or EventsList
+        Event window, list or dict of events to exclude from the analysis.
 
     Raises
     ------
@@ -199,7 +199,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         else:
             raise ValueError('Invalid input Ephemeris Time(s).')
 
-        if isinstance(self.exclude, (EventWindow, EventsList)):
+        if isinstance(self.exclude, (EventWindow, EventsDict, EventsList)):
             cond = self.exclude.contains(self.utc)
             self.__ets = self.__ets[~cond]
             del self.utc
@@ -269,7 +269,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        np.ndarray
+        numpy.ndarray
             Spacecraft XYZ intersection on the target body fixed frame
             (expressed in km).
 
@@ -278,16 +278,6 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         Currently the intersection method is fixed internally
         as ``method='NEAR POINT/ELLIPSOID'``.
 
-        See Also
-        --------
-        Trajectory.lonlat
-        Trajectory.rlonlat
-        Trajectory.lon_e
-        Trajectory.lat
-        Trajectory.local_time
-        Trajectory.illum_angles
-        Trajectory.solar_zenith_angle
-
         """
         log_traj.info('Compute sub-spacecraft points.')
         res = sub_obs_pt(
@@ -306,7 +296,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        np.ndarray
+        numpy.ndarray
             Sub-spacecraft planetocentric coordinates:
             radii, east longitudes and latitudes.
 
@@ -317,9 +307,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sc_pts
-        Trajectory.lon_e
-        Trajectory.lat
+        .sc_pts
 
         """
         log_traj.debug('Compute sub-observer point in planetocentric coordinates.')
@@ -336,7 +324,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        np.ndarray
+        numpy.ndarray
             Boresight XYZ intersection on the target body fixed frame
             (expressed in km).
 
@@ -363,13 +351,13 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        np.ndarray
+        numpy.ndarray
             Boresight surface intersect planetocentric coordinates:
             radii, east longitudes and latitudes.
 
         See Also
         --------
-        Trajectory.boresight_pts
+        .boresight_pts
 
         """
         log_traj.debug('Compute boresight intersect in planetocentric coordinates.')
@@ -393,12 +381,6 @@ class Trajectory:  # pylint: disable=too-many-public-methods
     @check_kernels
     def sc_state(self):
         """Spacecraft position and velocity in the target body fixed frame (km and km/s).
-
-        See Also
-        --------
-        Trajectory.sc_pos
-        Trajectory.alt
-
         """
         log_traj.info('Compute spacecraft position and velocity in the target frame.')
         res = sc_state(
@@ -416,8 +398,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.dist
-        Trajectory.alt
+        .sc_state
 
         """
         return self.sc_state[:3]
@@ -428,7 +409,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sc_speed
+        .sc_speed
 
         """
         return self.sc_state[3:]
@@ -439,7 +420,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sc_velocity
+        .sc_velocity
 
         """
         return norm(self.sc_velocity.T)
@@ -452,9 +433,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sc_pos
-        Trajectory.alt
-        Trajectory.slant
+        .sc_state
 
         """
         log_traj.debug('Compute spacecraft distance in the target frame.')
@@ -469,9 +448,8 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sc_pts
-        Trajectory.sc_pos
-        Trajectory.dist
+        .sc_pts
+        .sc_state
 
         """
         log_traj.debug('Compute spacecraft distance in the target frame.')
@@ -481,12 +459,12 @@ class Trajectory:  # pylint: disable=too-many-public-methods
     def ets_target_center(self):
         """Ephemeris Time (ET) at the target center.
 
-        The light time correction is only apply if :py:attr:`abcorr` in not ``NONE``.
+        The light time correction is only apply if :attr:`abcorr` in not ``NONE``.
 
         See Also
         --------
-        Trajectory.dist
-        SpiceAbCorr.dist_corr
+        .dist
+        .SpiceAbCorr.dist_corr
 
         """
         return self.abcorr.dist_corr(self.ets, self.dist)
@@ -501,9 +479,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sc_state
-        Trajectory.sc_pos
-        Trajectory.sc_velocity
+        .sc_state
 
         """
         log_traj.info('Compute groundtrack velocity.')
@@ -549,11 +525,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        Trajectory.sun_rlonlat
-        Trajectory.sun_lon_e
-        Trajectory.sun_lat
-        Trajectory.sun_lonlat
-        Trajectory.solar_zenith_angle
+        .ets_target_center
 
         """
         log_traj.info('Compute Sun coordinates in the target frame.')
@@ -571,16 +543,13 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         Returns
         -------
-        np.ndarray
+        numpy.ndarray
             Sub-solar planetocentric coordinates:
             radii, east longitudes and longitudes.
 
         See Also
         --------
-        Trajectory.sun_pos
-        Trajectory.sun_lon_e
-        Trajectory.sun_lat
-        Trajectory.sun_lonlat
+        .sun_pos
 
         """
         log_traj.debug('Compute sub-solar point in planetocentric coordinates.')
@@ -671,8 +640,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         Raises
         ------
         AttributeError
-            If the comparison object doest have a :py:func:`constains`
-            test function.
+            If the comparison object doest have a :func:`contains` test function.
 
         """
         if not hasattr(obj, 'contains'):
@@ -692,7 +660,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
         Danger
         ------
         These values may not be accurate depending on the
-        :py:class:`Trajectory` temporal resolution.
+        :class:`Trajectory` temporal resolution.
 
         """
         dist_min = self.target.radius + alt_min
@@ -729,7 +697,7 @@ class Trajectory:  # pylint: disable=too-many-public-methods
 
         See Also
         --------
-        :py:func:`get_flybys` if you need a different minimal altitude.
+        :func:`get_flybys` if you need a different minimal altitude.
 
         """
         return self.get_flybys()
@@ -772,12 +740,12 @@ class SpacecraftTrajectory(Trajectory):
     def ets_surface_intersect(self):
         """Ephemeris Time (ET) at the surface intersect point.
 
-        The light time correction is only apply if :py:attr:`abcorr` in not ``NONE``.
+        The light time correction is only apply if :attr:`abcorr` in not ``NONE``.
 
         See Also
         --------
         Trajectory.alt
-        SpiceAbCorr.dist_corr
+        .SpiceAbCorr.dist_corr
 
         """
         return self.abcorr.dist_corr(self.ets, self.alt)
@@ -789,7 +757,8 @@ class SpacecraftTrajectory(Trajectory):
 
         See Also
         --------
-        Trajectory.rlonlat
+        .sc_rlonlat
+        .ets_surface_intersect
 
         """
         log_traj.info('Compute sub-spacecraft local time.')
@@ -804,10 +773,8 @@ class SpacecraftTrajectory(Trajectory):
 
         See Also
         --------
-        Trajectory.inc
-        Trajectory.emi
-        Trajectory.phase
-        Trajectory.sc_pts
+        .sc_pts
+        .ets_surface_intersect
 
         """
         log_traj.info('Compute sub-spacecraft illumination geometry.')
@@ -863,7 +830,7 @@ class SpacecraftTrajectory(Trajectory):
 
         See Also
         --------
-        Trajectory.sc_pts
+        .sc_pts
 
         """
         log_traj.debug('Compute sub-observer local normal.')
@@ -883,8 +850,8 @@ class SpacecraftTrajectory(Trajectory):
         See Also
         --------
         Trajectory.sun_pos
-        Trajectory.sc_pts
-        Trajectory.ell_norm
+        .sc_pts
+        .ell_norm
 
         """
         # pylint: disable=no-member
@@ -915,7 +882,14 @@ class InstrumentTrajectory(Trajectory):
 
     @cached_property(parent=('sc_pts', 'boresight_pts'))
     def slant(self):
-        """Line-of-sight distance to the boresight surface intersection (km)."""
+        """Line-of-sight distance to the boresight surface intersection (km).
+
+        See Also
+        --------
+        .sc_pts
+        .boresight_pts
+
+        """
         log_traj.debug('Compute slant range to the boresight surface intersection.')
         return norm(self.sc_pos.T - self.boresight_pts.T)
 
@@ -923,12 +897,12 @@ class InstrumentTrajectory(Trajectory):
     def ets_surface_intersect(self):
         """Ephemeris Time (ET) at the surface intersect point.
 
-        The light time correction is only apply if :py:attr:`abcorr` in not ``NONE``.
+        The light time correction is only apply if :attr:`abcorr` in not ``NONE``.
 
         See Also
         --------
-        Trajectory.slant
-        SpiceAbCorr.dist_corr
+        .slant
+        .SpiceAbCorr.dist_corr
 
         """
         return self.abcorr.dist_corr(self.ets, self.slant)
@@ -949,10 +923,8 @@ class InstrumentTrajectory(Trajectory):
 
         See Also
         --------
-        Trajectory.inc
-        Trajectory.emi
-        Trajectory.phase
-        Trajectory.boresight_pts
+        .boresight_pts
+        .ets_surface_intersect
 
         """
         log_traj.info('Compute boresight intersection illumination geometry.')
@@ -1008,7 +980,7 @@ class InstrumentTrajectory(Trajectory):
 
         See Also
         --------
-        Trajectory.boresight_pts
+        .boresight_pts
 
         """
         log_traj.debug('Compute sub-observer local normal.')
@@ -1028,8 +1000,8 @@ class InstrumentTrajectory(Trajectory):
         See Also
         --------
         Trajectory.sun_pos
-        Trajectory.boresight_pts
-        Trajectory.ell_norm
+        .boresight_pts
+        .ell_norm
 
         """
         # pylint: disable=no-member
@@ -1092,15 +1064,15 @@ class Flyby(Trajectory):
 
         `(duration, numpy.datetime unit, step value and unit)`
 
-        See :py:func:`moon_coverage.spice.et_ca_range` for more details.
+        See :func:`.et_ca_range` for more details.
 
     abcorr: str, optional
         Aberration corrections to be applied when computing
         the target's position and orientation.
         Only the SPICE keys are accepted.
 
-    exclude: EventWindow or EventsList
-        Event window or list of events to exclude from the analysis.
+    exclude: EventWindow, EventsDict or EventsList
+        Event window, dict or list of events to exclude from the analysis.
 
     alt_min: float, optional
         Altitude minimal to a given target [km] (default: 25,000 km).
@@ -1108,7 +1080,7 @@ class Flyby(Trajectory):
     See Also
     --------
     Trajectory
-    moon_coverage.spice.et_ca_range
+    .et_ca_range
 
     """
     def __init__(self, kernels, observer, target, approx_ca_utc, *dt,
@@ -1141,11 +1113,11 @@ class Flyby(Trajectory):
 
             `(duration, numpy.datetime unit, step value and unit)`
 
-            See :py:func:`moon_coverage.spice.et_ca_range` for more details.
+            See :func:`moon_coverage.spice.et_ca_range` for more details.
 
         Returns
         -------
-        np.ndarray
+        numpy.ndarray
             Ephemeris times around CA.
 
         Raises
